/*
 * Copyright 2011 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ${package}.activity;

import java.util.LinkedHashMap;
import java.util.Map;

import ${package}.R;
import ${package}.activity.fragment.WebViewFragment;
import org.meruvian.midas.view.DashboardLayout;
import org.meruvian.midas.view.adapter.ActionInfo;
import org.meruvian.midas.view.lib.ActionBarActivity;

import roboguice.inject.InjectFragment;
import roboguice.inject.InjectView;
import android.content.Intent;
import android.content.res.Resources;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Toast;

import com.google.inject.internal.Nullable;

/**
 * @author Dias Nurul Arifin
 * @author Dian Aditya
 * 
 */
public class DashboardActivity extends ActionBarActivity {

	@InjectView(R.id.gvMain)
	private DashboardLayout dashboardLayout;

	@InjectFragment(R.id.webview_fragment)
	@Nullable
	private WebViewFragment viewFragment;

	private Map<String, String> info = new LinkedHashMap<String, String>() {
		private static final long serialVersionUID = 7484272704025844888L;
		{
			put("Google", "google.com");
			put("Facebook", "facebook.com");
			put("Twitter", "twitter.com");
			put("Gmail", "gmail.com");
			put("Yahoo!", "yahoo.com");
			put("Flickr", "flickr.com");
		}
	};

	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.dashboard_fragment);

		Resources resources = getResources();

		for (String icon : info.keySet()) {
			dashboardLayout.addActionInfo(new ActionInfo(BitmapFactory
					.decodeResource(resources, R.drawable.ic_launcher), icon));
		}

		dashboardLayout.setOnItemClickListener(new AdapterView.OnItemClickListener() {
			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1,
					int arg2, long arg3) {
				dahboardLayoutOnItemClick(arg0, arg1, arg2, arg3);
			}
		});
		
	}

	protected void dahboardLayoutOnItemClick(AdapterView<?> adapterView,
			View view, int index, long longg) {
		String url = info.values().toArray(new String[0])[index];
		if (viewFragment != null && viewFragment.isInLayout()) {
			viewFragment.updateUrl("http://" + url);
		} else {
			Intent showContent = new Intent(getApplicationContext(), WebViewActivity.class);
			showContent.setData(Uri.parse("http://" + url));
			startActivity(showContent);
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		MenuInflater menuInflater = getMenuInflater();
		menuInflater.inflate(R.menu.menu_dashboard, menu);
		return super.onCreateOptionsMenu(menu);
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		if (item.getItemId() == R.id.menu_refresh) {
			Toast.makeText(this, "Fake refreshing...", Toast.LENGTH_SHORT).show();
			getActionBarHelper().setRefreshActionItemState(true);
			getWindow().getDecorView().postDelayed(new Runnable() {
				@Override
				public void run() {
					getActionBarHelper().setRefreshActionItemState(false);
				}
			}, 1000);
		} else if (item.getItemId() == R.id.menu_search) {
			Toast.makeText(this, "Tapped search", Toast.LENGTH_SHORT).show();
		} else if (item.getItemId() == R.id.menu_list_mode) {
			
		}
		return super.onOptionsItemSelected(item);
	}
}
